@@ -41,7 +41,7 @@ _translate_table = string.maketrans('acgt', 'NNNN')
 def mask_lower(seq):
     "Create a new sequence where lower case A,C,G,T are replaced with Ns. Useful for masking UCSC data."
     return corebio.seq.Seq(
-        seq.translate(_translate_table),
+        seq.tostring().translate(_translate_table),
         name='%s (lower masked)' % seq.name,
         description='%s (lower masked)' % seq.description,
         alphabet=seq.alphabet,
